@@ -41,7 +41,8 @@ CONFIGS = [
 
 CONFIG = {"frequency": 22050, "size": -16, "channels": 2}  # base config
 if pygame.get_sdl_version()[0] >= 2:
-    CONFIG = {"frequency": 44100, "size": 32, "channels": 2}  # base config
+    # base config
+    CONFIG = {"frequency": 44100, "size": 32, "channels": 2, "allowedchanges": 0}  
 
 
 class InvalidBool(object):
@@ -86,7 +87,7 @@ class MixerModuleTest(unittest.TestCase):
         # default values. No way to check buffer size though.
         mixer.pre_init(22050, -8, 1)  # Non default values
         mixer.pre_init(0, 0, 0)  # Should reset to default values
-        mixer.init()
+        mixer.init(allowedchanges=0)
         self.assertEqual(mixer.get_init()[0], 44100)
         self.assertEqual(mixer.get_init()[1], -16)
         self.assertGreaterEqual(mixer.get_init()[2], 2)
@@ -490,23 +491,48 @@ class MixerModuleTest(unittest.TestCase):
 
         self.fail()
 
-    def todo_test_find_channel(self):
-
+    def test_find_channel(self):
         # __doc__ (as of 2008-08-02) for pygame.mixer.find_channel:
 
         # pygame.mixer.find_channel(force=False): return Channel
         # find an unused channel
-        #
-        # This will find and return an inactive Channel object. If there are
-        # no inactive Channels this function will return None. If there are no
-        # inactive channels and the force argument is True, this will find the
-        # Channel with the longest running Sound and return it.
-        #
-        # If the mixer has reserved channels from pygame.mixer.set_reserved()
-        # then those channels will not be returned here.
-        #
+        mixer.init()
+
+        filename = example_path(os.path.join("data", "house_lo.wav"))
+        sound = mixer.Sound(file=filename)
+
+        num_channels = mixer.get_num_channels()
+
+        if num_channels > 0:
+            found_channel = mixer.find_channel()
+            self.assertIsNotNone(found_channel)
+
+            # try playing on all channels
+            channels = []
+            for channel_id in range(0, num_channels):
+                channel = mixer.Channel(channel_id)
+                channel.play(sound)
+                channels.append(channel)
+
+            # should fail without being forceful
+            found_channel = mixer.find_channel()
+            self.assertIsNone(found_channel)
+
+            # try forcing without keyword
+            found_channel = mixer.find_channel(True)
+            self.assertIsNotNone(found_channel)
+
+            # try forcing with keyword
+            found_channel = mixer.find_channel(force=True)
+            self.assertIsNotNone(found_channel)
+
+            for channel in channels:
+                channel.stop()
+            found_channel = mixer.find_channel()
+            self.assertIsNotNone(found_channel)
+
+
 
-        self.fail()
 
     def todo_test_get_busy(self):
 
@@ -535,23 +561,32 @@ class MixerModuleTest(unittest.TestCase):
 
         self.fail()
 
-    def todo_test_set_reserved(self):
+    def test_set_reserved(self):
 
         # __doc__ (as of 2008-08-02) for pygame.mixer.set_reserved:
 
-        # pygame.mixer.set_reserved(count): return None
-        # reserve channels from being automatically used
-        #
-        # The mixer can reserve any number of channels that will not be
-        # automatically selected for playback by Sounds. If sounds are
-        # currently playing on the reserved channels they will not be stopped.
-        #
-        # This allows the application to reserve a specific number of channels
-        # for important sounds that must not be dropped or have a guaranteed
-        # channel to play on.
-        #
+        # pygame.mixer.set_reserved(count): return count
+        mixer.init()
+        default_num_channels = mixer.get_num_channels()
 
-        self.fail()
+        # try reserving all the channels
+        result = mixer.set_reserved(default_num_channels)
+        self.assertEqual(result, default_num_channels)
+
+        # try reserving all the channels + 1
+        result = mixer.set_reserved(default_num_channels + 1)
+        # should still be default
+        self.assertEqual(result, default_num_channels)
+
+        # try unreserving all
+        result = mixer.set_reserved(0)
+        # should still be default
+        self.assertEqual(result, 0)
+
+        # try reserving half
+        result = mixer.set_reserved(int(default_num_channels/2))
+        # should still be default
+        self.assertEqual(result, int(default_num_channels/2))
 
     def todo_test_stop(self):
 
